unit testFileDeleter;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, FileCtrl, FileDeleter, ComCtrls, ExtCtrls, Menus;

type
  TfrmFileDeleterTest = class(TForm)
    OpenDialog1: TOpenDialog;
    SaveDialog1: TSaveDialog;
    MainMenu1: TMainMenu;
    miFile: TMenuItem;
    miOpen: TMenuItem;
    miSave: TMenuItem;
    N1: TMenuItem;
    miExit: TMenuItem;
    Panel1: TPanel;
    gbDirs: TGroupBox;
    dirListSelect: TDirectoryListBox;
    Panel2: TPanel;
    Label1: TLabel;
    Panel3: TPanel;
    lbSelDir: TLabel;
    Panel4: TPanel;
    btnAddDir: TButton;
    meDirs: TMemo;
    Panel5: TPanel;
    btnClearDirs: TButton;
    gbMasks: TGroupBox;
    Panel6: TPanel;
    edMask: TEdit;
    Panel7: TPanel;
    Label2: TLabel;
    Panel8: TPanel;
    btnAddMask: TButton;
    meMasks: TMemo;
    Panel9: TPanel;
    btnClearMasks: TButton;
    gbDelete: TGroupBox;
    Panel10: TPanel;
    cbRecDirs: TCheckBox;
    Panel11: TPanel;
    cbPreview: TCheckBox;
    Panel12: TPanel;
    btnDelete: TButton;
    meDeletedFiles: TMemo;
    Panel13: TPanel;
    btnClearAll: TButton;
    procedure FormCreate(Sender: TObject);
    procedure btnAddDirClick(Sender: TObject);
    procedure btnClearDirsClick(Sender: TObject);
    procedure dirListSelectChange(Sender: TObject);
    procedure btnAddMaskClick(Sender: TObject);
    procedure btnClearMasksClick(Sender: TObject);
    procedure cbRecDirsClick(Sender: TObject);
    procedure cbPreviewClick(Sender: TObject);
    procedure btnDeleteClick(Sender: TObject);
    procedure btnClearAllClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure miExitClick(Sender: TObject);
    procedure miOpenClick(Sender: TObject);
    procedure miSaveClick(Sender: TObject);
  private
    { Private declarations }
    fd : TFileDeleter;


  public
    { Public declarations }
  end;

var
  frmFileDeleterTest: TfrmFileDeleterTest;

implementation

{$R *.DFM}

procedure TfrmFileDeleterTest.FormCreate(Sender: TObject);
begin
//  Application.Title := 'File Deleter - Test';
  Application.Title := 'File Deleter - V1.0.2';
  frmFileDeleterTest.Caption := Application.Title;

  fd := TFileDeleter.create();
  try
    dirListSelect.Directory := 'C:\Documents and Settings\Fabio\Desktop';
  except
  end;

  dirListSelect.Directory := ExtractFileDir(Application.ExeName);
  SaveDialog1.InitialDir := ExtractFileDir(Application.ExeName);
end;

procedure TfrmFileDeleterTest.btnAddDirClick(Sender: TObject);
begin
  fd.addDirectory(lbSelDir.Caption);
  fd.getDirectories(meDirs.Lines);
end;

procedure TfrmFileDeleterTest.btnClearDirsClick(Sender: TObject);
begin
  fd.clearAllDirectories;
  fd.getDirectories(meDirs.Lines);
end;

procedure TfrmFileDeleterTest.dirListSelectChange(Sender: TObject);
begin
  lbSelDir.Caption := dirListSelect.Directory;
end;

procedure TfrmFileDeleterTest.btnAddMaskClick(Sender: TObject);
begin
  fd.addFileNameMask(edMask.Text);
  fd.getFileNameMasks(meMasks.Lines);
end;

procedure TfrmFileDeleterTest.btnClearMasksClick(Sender: TObject);
begin
  fd.clearAllFileNameMasks;
  fd.getFileNameMasks(meMasks.Lines);
  edMask.Text := '';
end;

procedure TfrmFileDeleterTest.cbRecDirsClick(Sender: TObject);
begin
  fd.setRecursiveDirs(cbRecDirs.Checked);
end;

procedure TfrmFileDeleterTest.cbPreviewClick(Sender: TObject);
begin
  fd.setPreviewMode(cbPreview.Checked);
end;

procedure TfrmFileDeleterTest.btnDeleteClick(Sender: TObject);
begin
  fd.delFiles(meDeletedFiles.Lines);
end;

procedure TfrmFileDeleterTest.btnClearAllClick(Sender: TObject);
begin
  fd.resetToDefault;

  cbRecDirs.Checked := False;
  cbPreview.Checked := False;
  meDeletedFiles.Clear;
  meDirs.Lines.Assign(fd.dirList);
  meMasks.Lines.Assign(fd.maskList);
  edMask.Text := '';
  
end;

procedure TfrmFileDeleterTest.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
  miExitClick(nil);
end;

procedure TfrmFileDeleterTest.miExitClick(Sender: TObject);
begin
  if MessageDlg('Do You  Want To Close ' + Application.Title + '?',
    mtConfirmation, [mbYes,mbNo], 0) = mrYes then
    Application.Terminate
  else
    Abort
end;

procedure TfrmFileDeleterTest.miOpenClick(Sender: TObject);
begin
  if OpenDialog1.Execute then
  begin
    fd.setParamsFileName(OpenDialog1.FileName);
    if fd.loadParamsFromFile = 0 then //no error
    begin
      fd.getDirectories(meDirs.Lines);
      fd.getFileNameMasks(meMasks.Lines);
      edMask.Text := '';
//      fd.setPreviewMode(True);
      cbPreview.Checked := fd.getPreviewMode;
      cbRecDirs.Checked := fd.getRecursiveDirs;
    end;
  end;
end;

procedure TfrmFileDeleterTest.miSaveClick(Sender: TObject);
var
  i : integer;
begin
  if SaveDialog1.Execute then
    if FileExists(SaveDialog1.FileName) and (MessageDlg(SaveDialog1.FileName + ' already exists.'
      +#13+#10+'Do you want to repalce it?', mtWarning, [mbYes,mbNo], 0) = mrYes) then
  begin
    fd.setParamsFileName(SaveDialog1.FileName);
    i := fd.saveParamsToFile;
    if i <> 0 then // error
      MessageDlg('An error occurred while trying to save this configuration to the file.'
        +#13+#10+'Error Code: ' + IntToStr(i), mtError, [mbOK], 0);
  end;
end;

end.
